@@ -1,20 +1,21 @@
+use strict;
 {
     package DBD::NullP;
 
     require DBI;
     require Carp;
 
-    @EXPORT = qw(); # Do NOT @EXPORT anything.
-    $VERSION = sprintf("12.%06d", q$Revision: 14895 $ =~ /(\d+)/o);
+    our @EXPORT = qw(); # Do NOT @EXPORT anything.
+    our $VERSION = "12.014715";
 
-#   $Id: NullP.pm 14895 2011-07-05 06:47:42Z REHSACK $
+#   $Id: NullP.pm 14714 2011-02-22 17:27:07Z Tim $
 #
 #   Copyright (c) 1994-2007 Tim Bunce
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file.
 
-    $drh = undef;	# holds driver handle once initialised
+    our $drh = undef;	# holds driver handle once initialised
 
     sub driver{
 	return $drh if $drh;
@@ -35,13 +36,13 @@
 
 
 {   package DBD::NullP::dr; # ====== DRIVER ======
-    $imp_data_size = 0;
+    our $imp_data_size = 0;
     use strict;
 
     sub connect { # normally overridden, but a handy default
         my $dbh = shift->SUPER::connect(@_)
             or return;
-        $dbh->STORE(Active => 1); 
+        $dbh->STORE(Active => 1);
         $dbh;
     }
 
@@ -51,7 +52,7 @@
 
 
 {   package DBD::NullP::db; # ====== DATABASE ======
-    $imp_data_size = 0;
+    our $imp_data_size = 0;
     use strict;
     use Carp qw(croak);
 
@@ -82,7 +83,10 @@
             # convert AutoCommit values to magic ones to let DBI
             # know that the driver has 'handled' the AutoCommit attribute
             $value = ($value) ? -901 : -900;
-	}
+	} elsif ($attrib eq 'nullp_set_err') {
+           # a fake attribute to produce a test case where STORE issues a warning
+           $dbh->set_err($value, $value);
+        }
 	return $dbh->SUPER::STORE($attrib, $value);
     }
 
@@ -96,7 +100,7 @@
 
 
 {   package DBD::NullP::st; # ====== STATEMENT ======
-    $imp_data_size = 0;
+    our $imp_data_size = 0;
     use strict;
 
     sub bind_param {
@@ -105,18 +109,18 @@
         $sth->{ParamAttr}{$param}   = $attr
             if defined $attr; # attr is sticky if not explicitly set
         return 1;
-    }       
+    }
 
     sub execute {
 	my $sth = shift;
         $sth->bind_param($_, $_[$_-1]) for (1..@_);
         if ($sth->{Statement} =~ m/^ \s* SELECT \s+/xmsi) {
-            $sth->STORE(NUM_OF_FIELDS => 1); 
+            $sth->STORE(NUM_OF_FIELDS => 1);
             $sth->{NAME} = [ "fieldname" ];
             # just for the sake of returning something, we return the params
             my $params = $sth->{ParamValues} || {};
             $sth->{dbd_nullp_data} = [ @{$params}{ sort keys %$params } ];
-            $sth->STORE(Active => 1); 
+            $sth->STORE(Active => 1);
         }
         # force a sleep - handy for testing
         elsif ($sth->{Statement} =~ m/^ \s* SLEEP \s+ (\S+) /xmsi) {
@@ -132,7 +136,7 @@
         elsif ($sth->{Statement} =~ m/^ \s* ERROR \s+ (\d+) \s* (.*) /xmsi) {
             return $sth->set_err($1, $2);
         }
-        # anything else is silently ignored, sucessfully
+        # anything else is silently ignored, successfully
 	1;
     }
 
